<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte, prosím, tento program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Pracovní výkaz</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Společnost:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresa:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefon:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>El. pošta:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Stránky:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nedostupné</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Měnový symbol uvést na začátku</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Hodinová sazba:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Daňová sazba:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Měnový symbol:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Spojení</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Stránka (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>Outlook CSV (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Vyvést zprávu</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Zobrazit zprávy</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Vytvořit zprávu</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Telefon: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Mezisoučet</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Daně</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Úhrn</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>Jedna hodina</numerusform>
            <numerusform>%n hodiny</numerusform>
            <numerusform>%n hodin</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 hodin</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Přidat sezení</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Začátek:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Konec:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Úkol:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Upravit sezení</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished">Úhrn</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Spustit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Zastavit</translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished">Hodiny</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Projekt</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sezení</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Delete</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Sloupce</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Desetinné zobrazení času</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Přímé zpracování hodnot</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jazyk &amp;programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Časomíra</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Ukázat vše</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Ukázat pouze nevyúčtované hodiny</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Ukázat pouze tento rok</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Ukázat pouze tento měsíc</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Ukázat pouze tento týden</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorské právo &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Nelze přečíst data času.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Nelze zapsat data času.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Běží časomíry. Zastavit časomíry a ukončit?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Program pro evidenci pracovní doby na počítači, který vám pomůže sledovat vámi strávený čas.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Vytvořit zprávu...</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Zobrazit &amp;zprávy</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Zrušit toto sezení?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Přidat projekt</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Zadat název projektu:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Nelze vytvořit umístění pro data času.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Nelze přesunout umístění pro data času.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Projekt s tímto názvem již existuje.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Odstranit vybraný projekt?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Odstranit vybrané sezení?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>Běží %n časomíra</numerusform>
            <numerusform>Běží %n časomíry</numerusform>
            <numerusform>Běží %n časomír</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Evidence pracovní doby Kapow</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
